@@ -1,11 +1,11 @@
 Tperm.sample <-
 function(x, fac, nperm) {
-    obs = rowttests(x, fac, tstatOnly= T)$statistic
+    obs = genefilter::rowttests(x, fac, tstatOnly= T)$statistic
 	names(obs)=rownames(x)
 	perms= matrix(NA,  nrow(x),  nperm)
 	
 	for(t1 in 1:nperm){
-		perms[,t1]=rowttests(x, sample(fac), tstatOnly= T)$statistic
+		perms[,t1]=genefilter::rowttests(x, sample(fac), tstatOnly= T)$statistic
 	}
 	rownames(perms)=rownames(x)
 	colnames(perms)=paste('B',1:nperm,sep="")
